Cubes
=====

This chapter describes how to define your own cubes and reuse already available cubes.

.. toctree::
   :maxdepth: 1

   what-is-a-cube.rst
   layout.rst
   installing-cubes.rst
   cc-newcube.rst
   available-cubes.rst
